==> flutter_helper-0.0.8.tar.gz: lib/src/Views/ImagesPickerView.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_helper/flutter_helper.dart';
import 'package:flutter_helper/src/Views/ImagePickerView.dart';
import 'package:quiver/iterables.dart';

class ImagesPickerView extends StatelessWidget {
  final List<String> images;
  final Function addImage;
  final Function(String) removeImage;
  final bool isLoading;
  final int itemCount;
  final List<String> texts;
  final int crossItemCount;

  ImagesPickerView({
    this.images,
    this.addImage,
    this.removeImage,
    this.isLoading,
    this.itemCount,
    this.texts,
    this.crossItemCount
  });

  List<Widget> _getPaddedChildren(List<Widget> children) {
    return GetPaddedChildrenUtil().getPaddedChildren(children);
  }

  Widget _buildPictures(BuildContext context) {
    final List<Widget> children = [for (var i = 0; i < (itemCount ?? 6); i++) ImagePickerView(i: i, addImage: addImage, removeImage: removeImage, isLoading: isLoading, images: images)];

    if (itemCount > 3) {
      final List partitionedChildren = partition(children, (crossItemCount ?? 2)).toList();

      return Column(
        children: _getPaddedChildren([for (var i = 0; i < partitionedChildren.length; i++) Column(children: [
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: Text("${texts[i]}", style: TextStyle(fontSize: 18.0, fontWeight: FontWeight.w600),),
          ),
          Row(mainAxisAlignment: MainAxisAlignment.spaceEvenly, children: partitionedChildren[i])
        ],)]),
      );
    } else {
      return Column(
        children: _getPaddedChildren([for (var i = 0; i < children.length; i++) Column(children: [
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: Text("${texts[i]}", style: TextStyle(fontSize: 18.0, fontWeight: FontWeight.w600),),
          ),
          children[i]
        ],)]),
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    return _buildPictures(context);
  }

}

==> flutter_helper-0.0.11.tar.gz: lib/src/Views/ImagesPickerView.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_helper/flutter_helper.dart';
import 'package:flutter_helper/src/Views/ImagePickerView.dart';
import 'package:quiver/iterables.dart';

class ImagesPickerView extends StatelessWidget {
  final List images;
  final Function addImage;
  final Function(String) removeImage;
  final bool isLoading;
  final int itemCount;
  final List<String> texts;
  final int crossItemCount;

  ImagesPickerView({
    this.images,
    this.addImage,
    this.removeImage,
    this.isLoading,
    this.itemCount,
    this.texts,
    this.crossItemCount
  });

  List<Widget> _getPaddedChildren(List<Widget> children) {
    return ChildrenUtil().getAllPaddedChildren(children);
  }

  Widget _buildPictures(BuildContext context) {
    final List<Widget> children = [for (var i = 0; i < (itemCount ?? 6); i++) ImagePickerView(i: i, addImage: addImage, removeImage: removeImage, isLoading: isLoading, images: images)];

    if (itemCount > 3) {
      final List partitionedChildren = partition(children, (crossItemCount ?? 2)).toList();

      return Column(
        children: _getPaddedChildren([for (var i = 0; i < partitionedChildren.length; i++) Column(children: [
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: Text("${texts[i]}", style: TextStyle(fontSize: 18.0, fontWeight: FontWeight.w600),),
          ),
          Row(mainAxisAlignment: MainAxisAlignment.spaceEvenly, children: partitionedChildren[i])
        ],)]),
      );
    } else {
      return Column(
        children: _getPaddedChildren([for (var i = 0; i < children.length; i++) Column(children: [
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: Text("${texts[i]}", style: TextStyle(fontSize: 18.0, fontWeight: FontWeight.w600),),
          ),
          children[i]
        ],)]),
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    return _buildPictures(context);
  }
}
